@@ -20,6 +20,4 @@ from cad_tickers.exchanges.tsx import (
 )
 from cad_tickers.exchanges.classes import CSETicker, CSESedarFilings
 
-# Example graphql endpoint data
-# for the tsx output
-# Ex: {"operationName":"findCompaniesByKeywords","variables":{"keywords":"zmd"},"query":"query findCompaniesByKeywords($keywords: String) {\n  findCompaniesByKeywords(keywords: $keywords) {\n    symbol\n    name\n    exchange\n    __typename\n  }\n}\n"}`
\ No newline at end of file
+from cad_tickers.exchanges.all_tickers import get_full_tickers
