@@ -46,7 +46,7 @@ def make_cse_path(raw_ticker: str, raw_industry: str) -> str:
     """
     if pd.isna(raw_industry):
         return ""
-    # verify raw_industry is in industry
+    # verify raw_industry is in industry do later
     cse_industries = [
         "Industry",
         "Mining",
@@ -56,7 +56,7 @@ def make_cse_path(raw_ticker: str, raw_industry: str) -> str:
         "Technology",
         "CleanTech",
     ]
-    # do later
+
     base_cse_url = "https://thecse.com/en/listings"
     industry = raw_industry.lower().replace(" ", "-")
     ticker = transform_name_to_slug(raw_ticker)
@@ -117,8 +117,9 @@ def cse_ticker_to_yahoo(row: pd.Series) -> str:
 def tsx_ticker_to_yahoo(row: pd.Series) -> str:
     """
     Parameters:
-      ticker - ticker from pandas dataframe from cad_tickers
-      exchange - what exchange the ticker is for
+      row - pd.Series
+        * Ticker - ticker from pandas dataframe from cad_tickers
+        * Ex. - what exchange the ticker is for
     Returns:
       yticker - yahoo finance ticker for tsx
     """
@@ -127,4 +128,14 @@ def tsx_ticker_to_yahoo(row: pd.Series) -> str:
     # 1min, 5min, 15min, 30min, 60min, daily, weekly, monthly
     switcher = {"TSXV": "V", "TSX": "TO"}
     yahoo_ex = switcher.get(exchange, "TSXV")
-    return f"{ticker}.{yahoo_ex}"
\ No newline at end of file
+    return f"{ticker}.{yahoo_ex}"
+
+
+def cse_ticker_to_webmoney(cse_ticker: str):
+    """
+    Parameters:
+      cse_ticker - cse ticker name
+    Returns:
+      webmoney_ticker - ticker that can be looked up in webmoney
+    """
+    return f"{cse_ticker}:CNX"
\ No newline at end of file
